Objects of Vectors
::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   enumerated_types.rst
   switch_statement.rst
   decks.rst
   another_constructor.rst
   deck_member_functions.rst
   shuffling.rst
   sorting.rst
   subdecks.rst
   shuffling_and_dealing.rst
   mergesort.rst
   glossary.rst
   Exercises.rst
   mixed_up_code.rst
   coding_practice.rst
